
# Class: download problem


A problem in downloading a knowledge source

URI: [http://example.org/sample/example1/DownloadProblem](http://example.org/sample/example1/DownloadProblem)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Problem],[Problem]^-[DownloadProblem&#124;has_source:string%20%3F;description(i):string%20%3F])](https://yuml.me/diagram/nofunky;dir:TB/class/[Problem],[Problem]^-[DownloadProblem&#124;has_source:string%20%3F;description(i):string%20%3F])

## Parents

 *  is_a: [Problem](Problem.md) - An object representing an error or problem encountered

## Attributes


### Own

 * [has source](has_source.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)

### Inherited from problem:

 * [description](description.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
